@@ -1,4 +1,4 @@
-/* scattering.h -- This file is part of Archimedes release 0.1.0
+/* scattering.h -- This file is part of Archimedes release 0.1.2
    Archimedes is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements the Monte Carlo method
    for the simulation of the semiclassical Boltzmann equation for both
@@ -25,7 +25,7 @@
 
 // ######################################################
 // Created on 06 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 10 Sep.2007, Siracusa, J.M.Sellier
+// Last modif. : 13 Sep.2007, Siracusa, J.M.Sellier
 // ######################################################
 
 // calculation of the various scattering process
@@ -99,9 +99,9 @@ scat(int Material)
    ki=sqrt(ksquared);
    thesquareroot=sqrt(1.+4.*alphaK[Material][IV]*HHM[Material][IV]*ksquared);
    superparticle_energy=(thesquareroot-1.)/(2.*alphaK[Material][IV]);
-  if(superparticle_energy<=0.) return;
-  ie=((int)(superparticle_energy/DE))+1;
-  if(ie>DIME) ie=DIME;
+   if(superparticle_energy<=0.) return;
+   ie=((int)(superparticle_energy/DE))+1;
+   if(ie>DIME) ie=DIME;
 
 // Selection of scattering process in the GAMMA-Valley
 // ===================================================
@@ -112,6 +112,7 @@ scat(int Material)
       if(r1<=SWK[Material][1][1][ie] && j==0){
          finalenergy=superparticle_energy-HWO[Material][0];
          if(finalenergy<=0.) return;
+//         if(finalenergy>DIME*DE) finalenergy=BKTQ;
          j=1;
 // linea 20
        kf=SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
@@ -143,7 +144,8 @@ scat(int Material)
 // Absorption of an optical phonon
       if((r1<=SWK[Material][1][2][ie]) && j==0){
          finalenergy=superparticle_energy+HWO[Material][0];
-         if(finalenergy<=0.) return;
+//         if(finalenergy<0.) return;
+//         if(finalenergy>DIME*DE) finalenergy=BKTQ;
          j=1;
 // linea 20
        kf=SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
@@ -174,8 +176,9 @@ scat(int Material)
       }
 // Emission
       if((r1<=SWK[Material][1][3][ie]) && j==0){
-         finalenergy=superparticle_energy-HWO[Material][0]+EC[1]-EC[2];
-         if(finalenergy<0.) return;
+         finalenergy=superparticle_energy-HWO[Material][0]+EMIN[Material][1]-EMIN[Material][2];
+         if(finalenergy<=0.) return;
+//         if(finalenergy>DIME*DE) finalenergy=BKTQ;
          IV=2;
          j=1;
 // determination of the final states
@@ -190,8 +193,9 @@ scat(int Material)
       }
 // Absorption
       if((r1<=SWK[Material][1][4][ie]) && j==0){
-         finalenergy=superparticle_energy+HWO[Material][0]+EC[1]-EC[2];
-         if(finalenergy<0.) return;
+         finalenergy=superparticle_energy+HWO[Material][0]+EMIN[Material][1]-EMIN[Material][2];
+         if(finalenergy<=0.) return;
+//         if(finalenergy>DIME*DE) finalenergy=BKTQ;
          IV=2;
          j=1;
 // determination of the final states
@@ -207,7 +211,7 @@ scat(int Material)
 // Acoustic phonon
     if((r1<=SWK[Material][1][5][ie]) && j==0){
        finalenergy=superparticle_energy;
-       if(finalenergy<=0.) return;
+//       if(finalenergy<0.) return;
        finalk=sqrt(ksquared);
        j=1;
 // determination of the final states
@@ -223,7 +227,7 @@ scat(int Material)
 // Impurity scattering
     if((r1<=SWK[Material][1][6][ie]) && j==0){
      finalenergy=superparticle_energy;
-     if(finalenergy<=0.) return;
+//     if(finalenergy<0.) return;
      r2=rnd();
      cb=1.-r2/(0.5+(1.-r2)*ksquared/QD2);
      kf=ki;
@@ -250,16 +254,17 @@ scat(int Material)
      return;
     }
     if((finalenergy<=0.) || j==0) return;
+//    if(finalenergy>DIME*DE) finalenergy=BKTQ;
 
 // determination of the final states
-    finalk = SMH[Material][1]*sqrt(finalenergy*(1.+alphaK[Material][1]*finalenergy));
+/*    finalk = SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
     cosinus = 1.-2.*rnd();
     sinus = sqrt(1.-cosinus*cosinus);
     fai = 2.*PI*rnd();
     KX = finalk*cosinus;
     KY = finalk*sinus*cos(fai);
     KZ = finalk*sinus*sin(fai);
-    return;
+    return;*/
    }
 // Selection of scattering process in the L-Valley
 // ===================================================
@@ -270,6 +275,7 @@ scat(int Material)
       if(r1<=SWK[Material][2][1][ie] && j==0){
          finalenergy=superparticle_energy-HWO[Material][0];
          if(finalenergy<=0.) return;
+//         if(finalenergy>DIME*DE) finalenergy=BKTQ;
          j=1;
 // linea 20
        kf=SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
@@ -301,7 +307,8 @@ scat(int Material)
 // Absorbation of an optical phonon
       if((r1<=SWK[Material][2][2][ie]) && j==0){
          finalenergy=superparticle_energy+HWO[Material][0];
-         if(finalenergy<=0.) return;
+//         if(finalenergy<=0.) return;
+//         if(finalenergy>DIME*DE) finalenergy=BKTQ;
          j=1;
 // linea 20
        kf=SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
@@ -334,6 +341,7 @@ scat(int Material)
     if((r1<=SWK[Material][2][3][ie]) && j==0){
        finalenergy=superparticle_energy-HWO[Material][0];
        if(finalenergy<=0.) return;
+//       if(finalenergy>DIME*DE) finalenergy=DIME*DE;
        j=1;
 // determination of the final states
        kf = SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
@@ -349,6 +357,7 @@ scat(int Material)
     if((r1<=SWK[Material][2][4][ie]) && j==0){
        finalenergy=superparticle_energy+HWO[Material][0];
        if(finalenergy<=0.) return;
+//       if(finalenergy>DIME*DE) finalenergy=BKTQ;
        j=1;
 // determination of the final states
        kf = SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
@@ -362,8 +371,9 @@ scat(int Material)
     }
 // Emission
     if((r1<=SWK[Material][2][5][ie]) && j==0){
-       finalenergy=superparticle_energy-HWO[Material][0]+EC[2]-EC[1];
-       if(finalenergy<0.) return;
+       finalenergy=superparticle_energy-HWO[Material][0]+EMIN[Material][2]-EMIN[Material][1];
+       if(finalenergy<=0.) return;
+//       if(finalenergy>DIME*DE) finalenergy=BKTQ;
        IV=1;
        j=1;
 // determination of the final states
@@ -378,8 +388,9 @@ scat(int Material)
     }
 // Absorbation
     if((r1<=SWK[Material][2][6][ie]) && j==0){
-       finalenergy=superparticle_energy+HWO[Material][0]+EC[2]-EC[1];
-       if(finalenergy<0.) return;
+       finalenergy=superparticle_energy+HWO[Material][0]+EMIN[Material][2]-EMIN[Material][1];
+       if(finalenergy<=0.) return;
+//       if(finalenergy>DIME*DE) finalenergy=BKTQ;
        IV=1;
        j=1;
 // determination of the final states
@@ -395,7 +406,7 @@ scat(int Material)
 // Acoustic phonon emission
     if((r1<=SWK[Material][2][7][ie]) && j==0){
        finalenergy=superparticle_energy;
-       if(finalenergy<=0.) return;
+//       if(finalenergy<=0.) return;
        finalk=sqrt(ksquared);
        j=1;
 // determination of the final states
@@ -411,7 +422,7 @@ scat(int Material)
 // Impurity scattering
     if((r1<=SWK[Material][2][8][ie]) && j==0){
      finalenergy=superparticle_energy;
-     if(finalenergy<=0.) return;
+//     if(finalenergy<=0.) return;
      r2=rnd();
      cb=1.-r2/(0.5+(1.-r2)*ksquared/QD2);
      kf=ki;
@@ -438,16 +449,17 @@ scat(int Material)
      return;     
     }
     if((finalenergy<=0.) || j==0) return;
+//    if(finalenergy>DIME*DE) finalenergy=BKTQ;
 
 // determination of the final states
-    finalk = SMH[Material][2]*sqrt(finalenergy*(1.+alphaK[Material][2]*finalenergy));
+/*    finalk = SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
     cosinus = 1.-2.*rnd();
     sinus = sqrt(1.-cosinus*cosinus);
     fai = 2.*PI*rnd();
     KX = finalk*cosinus;
     KY = finalk*sinus*cos(fai);
     KZ = finalk*sinus*sin(fai);
-    return;
+    return;*/
    }
   }
 }
